ewa.config

Package ewa :: Module config |
[hide private]
[frames] | no frames]

# Module config

source code

A barebones config object loaded from a Python config file.

Classes | [hide private]
| _config

Functions | [hide private]
initConfig(configfile) | source code

Variables | [hide private]
| have_fork = `True`
| Config = `_config()`
| DEFAULTS = ``{``'``basedir``'``:` None`,` `'``content_disposition``'``:` `'``attachmen``...``
| __package__ = ``'``ewa``'``

Variables Details | [hide private]

  ### DEFAULTS Value:
      {'basedir': None,
       'content_disposition': 'attachment',
       'daemonize': True,
       'engine': 'default',
       'group': None,
       'interface': '127.0.0.1',
       'lame_path': '/usr/bin/lame',
       'logfile': None,
      ...